#!/usr/bin/php
<?php
define('PLUGIN_NAME', 'corr_http_response');
$ERRORS = array('OK' => 0,'WARNING' => 1,'CRITICAL' => 2,'UNKNOWN' => 3);
$SHORT_OPTS = 'n:f:d:hDw:c:e:';
$LONG_OPTS = array('node:','directory:','file:', 'help','debug', 'warning:','critical:','exclude:');
$priorities = array($ERRORS['CRITICAL'],
					$ERRORS['WARNING'],
					$ERRORS['UNKNOWN'],
					$ERRORS['OK']);
$options = getopt($SHORT_OPTS, $LONG_OPTS);
$file = getParam($options, 'f', 'file', '/usr/local/esia/public_html/esia.conf.php');
$directory 	= getParam($options, 'd', 'directory', '/usr/local/esia/public_html/');
$debug 	    = getParam($options,"D","Debug",NULL);
$nodeid 	= getParam($options,"n","node",NULL);
$warning  = getParam($options,"w","warning",1);
$critical = getParam($options,"c","critical",30);
$exclude = getParam($options,"e","exclude",NULL);
if(preg_match('#(.*)\/esia.conf#',$file,$regs))
{
	$_SERVER['DOCUMENT_ROOT'] = $regs[1].'/';
	trace($debug,'ROOT DIR: '.$_SERVER['DOCUMENT_ROOT']);
}
include_once $file;
include_once MVCMODEL;
include_once $_SERVER['DOCUMENT_ROOT'].'/plugin/syslog/libs/syslog.class.php';
try
{
	$dbconnection = new PDO('pgsql:host='.DB_HOST.';port='.DB_PORT.';dbname='.DB_NAME, DB_USERNAME, DB_PWD);
	$dbconnection->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_WARNING);
	$node = Model_esia::InstanceNode($dbconnection, $nodeid);
	trace($debug,"NODE FOUND (id: $nodeid): ".$node->getName());
	$syslog = new SyslogServer($node);
	$setting = Model_esia::getAdvanceNodeConfig($dbconnection,$syslog->getId(),'SYSLOG_URL')[0];
	if(!empty($setting))
	{
		$syslog->setURL($setting['parameter']['url']);
		$hosts = $syslog->getHosts(SyslogServer::OUTPUT_ARRAY);
		$exclude_number = 0;
		if(isset($exclude))
		{
			$arr = array();
			foreach($hosts as $host)
			{
				if(!preg_match("#$exclude#",$host))
				{
					$arr[] = $host;
				}
			}
			$exclude_number = count($hosts) - count($arr);
			$hosts = $arr;
		}
		trace($debug,"Récupération de noeuds déjà configuré");
		$advs = Model_esia::getAdvanceNodeConfigType($dbconnection,'SYSLOG')[0];
		$advs = Model_esia::getAdvanceNodeConfig($dbconnection,NULL,NULL,$advs['id']);
		trace($debug,$advs);
		$hostnames = array();
		foreach($advs as $adv)
		{
			if($adv['parameter']['syslog-server'] == $syslog->getId())
			{
				$hostnames[] = $adv['parameter']['host'];
			}
		}
		$arr = array_diff($hosts,$hostnames);
		
		$count = count($arr);
		$state = 'OK';
		if($count > $critical)
		{
			$state = 'CRITICAL';
		}
		elseif($count > $warning)
		{
			$state = 'WARNING';
		}
		echo "$state: there are $count hostname that not linked ($exclude_number excluded):\n";
		foreach($arr as $hostname)
		{
			echo "$hostname\n";
		}
		echo "|notlinked=$count;exclude=$exclude_number";
		exit($ERRORS[$state]);
	}
	else
	{
		echo "UNKNOWN: node is not a Syslog server. SYSLOG_URL not configure\n";
		exit($ERRORS['UNKNOWN']);
	}
}
catch(Exception $e)
{
	echo "UNKNOWN: node not found: ".$e->getMessage()."\n";
	exit($ERRORS['UNKNOWN']);
}

function trace($debug,$output)
{
	//if($debug==1 || $debug===true)
	if(isset($debug))
	{
		if(is_array($output))
		{
			print_r($output);
		}
		else
		{
			echo "DEBUG: $output\n";
		}
	}
}
function getParam($options, $shortName, $slongName, $default = NULL)
{
	$param = $default;
	if (isset($options[$shortName]))
	{
		$param = $options[$shortName];
	}
	elseif (isset($options[$slongName]))
	{
		$param = $options[$slongName];
	}
	// security for string
	if (is_string($param))
	{
		$param = strtolower(trim(str_replace(' ', '', $param)));
	}
	return $param;
}
?>